package com.xy.third.baidu;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import lombok.extern.slf4j.Slf4j;

import java.util.HashMap;
import java.util.Map;

/**
 * 百度翻译API接口
 */

@Slf4j
public class TransApi {
    private static final String TRANS_API_HOST = "https://fanyi-api.baidu.com/api/trans/vip/translate";
    private static final String APP_ID = "20240428002037687";
    private static final String SECURITY_KEY = "nXkFm4SaA2Wrmb42Xmky";
    private String appid;
    private String securityKey;

    public TransApi(String appid, String securityKey) {
        this.appid = appid;
        this.securityKey = securityKey;
    }

    /**
     * 调用百度翻译API
     *
     * @param query  待翻译的文本
     * @param lanSrc 原语言 zh
     * @param lanDst 目标语言 en
     * @return
     */
    public static String translate(String query, String lanSrc, String lanDst) {
        TransApi api = new TransApi(APP_ID, SECURITY_KEY);
        log.info("正在翻译文本：{}", query);
        JSONObject res = JSONUtil.parseObj(api.getTransResult(query, lanSrc, lanDst));
        JSONArray transResult = res.getJSONArray("trans_result");
        if (!JSONUtil.isNull(transResult)) {
            JSONObject jsonObject = transResult.getJSONObject(0);
            log.info("文本：{},翻译结果：{}", query, jsonObject.getStr("dst"));
            return jsonObject.getStr("dst");
        } else {
            log.info("文本：{},翻译失败：{}", query, JSONUtil.toJsonPrettyStr(res));
            return "";
        }
    }

    public String getTransResult(String query, String from, String to) {
        Map<String, String> params = buildParams(query, from, to);
        return HttpGet.get(TRANS_API_HOST, params);
    }

    private Map<String, String> buildParams(String query, String from, String to) {
        Map<String, String> params = new HashMap<String, String>();
        params.put("q", query);
        params.put("from", from);
        params.put("to", to);

        params.put("appid", appid);

        // 随机数
        String salt = String.valueOf(System.currentTimeMillis());
        params.put("salt", salt);

        // 签名
        String src = appid + query + salt + securityKey; // 加密前的原文
        params.put("sign", MD5.md5(src));

        return params;
    }


}
